@@ -3,7 +3,7 @@
    *  Secure Login Plugin
    *  By Graham Norbury <gnorbury@bondcar.com>
    *  Changes by Paul Lesneiwski <pdontthink@angrynerds.com>
-   *  v1.0 (c) 2002 (GNU GPL - see ../../COPYING)
+   *  v1.2 (c) 2002 (GNU GPL - see ../../COPYING)
    *
    *  This is a very simple plugin which enforces use of SSL security for logins.
    *
@@ -24,6 +24,14 @@
    }
 
 
+   function secure_login_version()
+   {
+
+      return '1.2';
+
+   }
+
+
    function secure_login_check()
    {
       
